@@ -1,6 +1,6 @@
 #!/usr/bin/perl -w
 # Author:   $Author: merkosh $
-# Revision: $Rev: 70 $
+# Revision: $Rev: 692 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -18,7 +18,7 @@
 #    You should have received a copy of the GNU General Public License     #
 #    along with this program; if not, write to the                         #
 #    Free Software Foundation, Inc.,                                       #
-#    59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             #
+#    51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA          #
 ############################################################################
 
 #---------------------------------------------------------#
@@ -31,6 +31,7 @@ use LWP::UserAgent;
 use HTTP::Request;
 use HTML::Entities;
 use File::Basename;
+use POSIX qw(ceil);
 
 use LMCTools;
 
@@ -184,7 +185,7 @@ if ($URL){
 
   # original title
   $tmp = &find($page, '<strong class="title">');
-  $data{'originalTitle'} = $1 if ($tmp =~ /\>([^\<]+) *\</);
+  $data{'originalTitle'} = decode_entities($1) if ($tmp =~ /\>([^\<]+) *\</);
 
   # year
   $tmp = &find($tmp, '<small>');
@@ -210,7 +211,7 @@ if ($URL){
 
   # director
   $tmp = &find($page, 'Directed by</b>');
-  $data{director} = $1 if ($tmp =~ /href\=.+?\>([^\<]+?)\</);
+  $data{director} = decode_entities($1) if ($tmp =~ /href\=.+?\>([^\<]+?)\</);
 
   # category
   $tmp = &find($page, '<b class="ch">Genre:</b>');
@@ -219,7 +220,7 @@ if ($URL){
     $tmp = &find($tmp, '<a href="/Sections/Genres/', 1);
     last unless ($tmp);
     $tmp =~ /\>(.+?)\</;
-    push @category, $1;
+    push @category, decode_entities($1);
   }
   $data{category} = join(", ", @category) if (scalar @category);
 
@@ -230,7 +231,7 @@ if ($URL){
     $tmp = &find($tmp, '<a href="/name/', 1);
     last unless ($tmp);
     $tmp =~ /\>(.+?)\<.+?\.\.\.\. .+?\"\>(.+?)\<\/td\>/;
-    push @actors, "$1 - $2";
+    push @actors, decode_entities($1)." - ".decode_entities($2);
   }
   $data{actors} = \@actors if (scalar @actors);
 
@@ -239,7 +240,7 @@ if ($URL){
   # if no rating available (first 100 char contain magic text)
   if (substr($tmp, 0, 100) !~ /awaiting \d votes/) {
     $tmp = &find($tmp, '<b>');
-    $data{rating} = $1 if ($tmp =~ /([\d\.]+)/);
+    $data{rating} = ceil($1) if ($tmp =~ /([\d\.]+)/);
   }
 
   # url
@@ -253,11 +254,11 @@ if ($URL){
 
   # country
   $tmp = &find($page, '<b class="ch">Country:</b>');
-  $data{country} = $1 if ($tmp =~ /href\=\".+?\"\>(.+?)\</);
+  $data{country} = decode_entities($1) if ($tmp =~ /href\=\".+?\"\>(.+?)\</);
 
   # language
   $tmp = &find($page, '<b class="ch">Language:</b>');
-  $data{languages} = $1 if ($tmp =~ /href\=\".+?\"\>(.+?)\</);
+  $data{languages} = decode_entities($1) if ($tmp =~ /href\=\".+?\"\>(.+?)\</);
 
   # description
   $tmp = &getPage($URL.'plotsummary')->content();
